import logging
import warnings

from odoo import models

_DEFAULT_LOGGER_NAME = __name__


class SimpleLogger(models.AbstractModel):
    _name = "runbot.logger"
    _description = "Logging Tester"

    def log_msg(self, msg, level=logging.INFO, logger_name=_DEFAULT_LOGGER_NAME):
        print(logging.getLogger(logger_name).handlers)
        print(logging.getLogger(logger_name).propagate)
        logging.getLogger(logger_name).log(level, msg)

    def do_pywarnings(self, msg, warning_type):
        warnings.warn(msg, warning_type, stacklevel=2)



import logging

from odoo.tests import common


class TestStep4(common.TransactionCase):
    def test_filter(self):
        # Step3 - Filter2 will capture this line but not Filter1 (no same logger name)
        self.env["runbot.logger"].log_msg("My Warning message - in root", level=logging.WARNING, logger_name=None)
        self.env["runbot.logger"].log_msg(
            "My Warning message - in custom", level=logging.WARNING, logger_name="Custom.logger"
        )
        self.env["runbot.logger"].log_msg(
            "My Warning message - in base", level=logging.WARNING, logger_name="odoo.addons.base"
        )
